WindowedStream

Struct WindowedStream 

pub struct WindowedStream<T> { /* private fields */ }
Represents a windowed stream for aggregation operations

Implementations

Source

impl<T> WindowedStream<T>
where T: Clone + Send + Sync + 'static,

pub fn aggregate<A, F>(self, init: A, f: F) -> DataStream<A>
where A: Clone + Send + Sync + 'static, F: Fn(A, T) -> A + Send + Sync + 'static,

Aggregate values in the window

pub fn any<F>(self, f: F) -> DataStream<bool>
where F: Fn(&T) -> bool + Send + Sync + 'static,

pub fn all<F>(self, f: F) -> DataStream<bool>
where F: Fn(&T) -> bool + Send + Sync + 'static,

pub fn limit(self, n: usize) -> DataStream<Vec<T>>

Limit the number of values in the window

pub fn tail(self, n: usize) -> DataStream<Vec<T>>

Retain last n values in the window

pub fn sort_by<F>(self, f: F) -> DataStream<Vec<T>>
where F: FnMut(&T, &T) -> Ordering + Send + Sync + 'static,

Sort values in the window

pub fn sort_by_ts(self, order: SortOrder) -> DataStream<Vec<T>>

Sort values in the window by timestamp

pub fn sort_by_ts_asc(self) -> DataStream<Vec<T>>

Sort values in the window by timestamp in ascending order

pub fn sort_by_ts_desc(self) -> DataStream<Vec<T>>

Sort values in the window by timestamp in descending order

pub fn skip(self, n: usize) -> DataStream<Vec<T>>

Skip

Source

impl<T> WindowedStream<T>
where T: Ord + Clone + Send + Sync + 'static,

pub fn sort(self, ord: SortOrder) -> DataStream<Vec<T>>

Sort values in specified order

pub fn top_k(self, k: usize) -> DataStream<Vec<T>>

Get the top k values in the window, the values are sorted in descending order

Source

impl<T> WindowedStream<T>
where T: Eq + Hash + Clone + Send + Sync + 'static,

pub fn distinct(self) -> DataStream<HashSet<T>>

Distinct values

Source

impl<T> WindowedStream<T>
where T: Clone + Send + Sync + 'static,

pub fn distinct_by_key<F, K>(self, f: F) -> DataStream<Vec<T>>
where F: Fn(&T) -> K + Sync + Send + 'static, K: Eq + Hash + Clone + Sync + Send + 'static,

Distinct values by key. When the same key is encountered, the first occurrence of the value is retained

pub fn top_k_by_key<F, K>(self, n: usize, f: F) -> DataStream<Vec<T>>
where F: Fn(&T) -> K + Sync + Send + 'static, K: Ord + Eq + Hash + Clone + Sync + Send + 'static,

Get top k values by key. The values are sorted by key in descending order